// Macro for creating histograms for the asymmetry analysis
// by Vincent Sulkosky, 08/06/2006
//
// batchified by J. Singh
//
// 1. requires run number and path of root files
// 2. opens "gdh_[run num]_replay.root" file from path, error checks open
// 3. does cuts and makes raw asymmetry histograms
// 4. saves histograms in "gdh_[run num]_aasym.root" file in current dir
//

void asym_histos(Int_t run_number = 0 , TString inbase = "_replay" , TString path = "/work/halla/gdh-3/gdh_rootfiles/")
{
	if (run_number == 0)
	{ cout << "Bummer dude, run number 0 does not exist.  Chances are the you forgot to specify a run number!" << endl; }
	else
	{
  		gSystem->Load("libAsymhisto.so");
		TString input_filename = path + "gdh_";
		input_filename += run_number;
		input_filename += inbase + ".root";
		cout << "Input file = " << input_filename << endl;
// Open root file and error checking open
		TFile *f1 = new TFile(input_filename.Data());
		if (f1->IsZombie())
		{ 
			cout << "Bummer dude, file = \"" << input_filename << "\" could not be opened." << endl; 
			cout << "Check to make sure that it exists and is really a root file." << endl;
		}
		else
		{
// Get the tree from the root file.
			TTree *gdhtree;
			gdhtree = (TTree*)gDirectory->Get("T");
// Create and initialize the GDH_class with the tree.
			GDH_class *asym = new GDH_class(gdhtree);
// Call the loop method to generate the histograms, automatically createis output file with name "gdh_[run num]_aasym.root"
			asym->Loop();
			cout << "Successfully opened replay root file, made cuts and histgrams, and wrote aasym root file for run " << run_number << endl;
		}
	}
}
