// Macro for creating histograms for GDH analysis
// by Vincent Sulkosky, updated on 11/17/2006
//
// batchified by J. Singh
//
// 1. requires run number and path of root files
// 2. opens "gdh_[run num]_replay.root" file from path, error checks open
// 3. does cuts and makes histograms according to analysis type:
//    aasym: asymmetry analysis
//    aaccept: acceptance plots
//    axs:   cross section analysis
//    adeff: detector efficiency analysis
// 4. saves histograms in "gdh_[run num]_[ana type].root" file in current dir
//

void gdh_histos(Int_t run_number = 0 , TString inbase = "_replay" , TString path = "/work/halla/gdh-3/gdh_rootfiles/", TString ana_type = "aasym")
{
	if (run_number == 0)
	{ cout << "Bummer dude, run number 0 does not exist.  Chances are the you forgot to specify a run number!" << endl; }
	else
	{
  		gSystem->Load("libGDHhistos.so");
		TString input_filename = path + "gdh_";
		input_filename += run_number;
		input_filename += inbase + ".root";
		cout << "Input file = " << input_filename << endl;
// Open root file and error checking open
		TFile *f1 = new TFile(input_filename.Data());
		if (f1->IsZombie())
		{ 
			cout << "Bummer dude, file = \"" << input_filename << "\" could not be opened." << endl; 
			cout << "Check to make sure that it exists and is really a root file." << endl;
		}
		else
		{
// Get the tree from the root file.
			TTree *gdhtree;
			gdhtree = (TTree*)gDirectory->Get("T");
// Create and initialize the GDH_class with the tree.
			GDH_class *gdhana = new GDH_class(gdhtree);
// Call the loop method to generate the histograms, automatically creates output file with name "gdh_[run num]_[ana type].root"
			if (ana_type == "aasym") 
			{
			  cout << "Creating asymmetry histograms." << endl;
			  gdhana->AsymLoop(ana_type);

			} else if (ana_type == "aaccept") 
			{
			  cout << "Creating acceptance histograms." << endl;
			  gdhana->AcptLoop(ana_type);
			} else if (ana_type == "axs") 
			{
			  cout << "Creating cross section histograms." << endl;
			  gdhana->CxsnLoop(ana_type);
			} else if (ana_type == "adeff") 
			{
			  cout << "Creating detector efficiency histograms." << endl;
			  gdhana->EffLoop(ana_type);
			} else 
			{
			  cout << "Bummer dude, analysis type = \"" << ana_type << "\" is not valid." << endl;
			  cout << "Exiting program ... " << endl;
			  exit(1);
			}

			
			cout << Form("Successfully opened replay root file, made cuts and histgrams, and wrote %s root file for run ", ana_type.Data()) << run_number << endl;
		}
	}
}

