// Rob/Vince's method should work
//
//	usage: .x replay.C ([run number] , [split file number] , [split control])
//		[split control] = "all"                , do all splits files
//		[split control] = "just the first one" , do just the first (split file number = 0) file
//
//	date: 07/28/06
//
//	by: Jaideep Singh (originally jacked from V. Sulkosky who jacked it from combination of R. Michaels and R. Feurbach
//
//	description: analzyer macro used to replay a raw data file, extract variables listed in def file, and create root file
//		     attempts to handle split runs
//

// void replay_rob_method(Int_t run_number = 2358 , Int_t split_number = 0, TString which_ones = "all" , TString test_path = "/cache/mss/halla/gdh/raw/")
void jtest(Int_t run_number = 2358 , Int_t split_number = 0, TString which_ones = "all" , TString test_path = "")
{
	TString allbase = "jtest";
// Set up equipment
// For sagGDH, the left and right spetrometer runs have to 
// be replayed separately.
// add one spectrometer with the "standard" configuration
// (VDC planes, S1, and S2)
	THaApparatus *HRSR = new THaHRS("R","Right arm HRS");
	gHaApps->Add(HRSR);
	HRSR->SetDebugAll(1);

// beam position and helicity
	THaApparatus *a = new THaIdealBeam("beam","Ideal beam");
	THaHelicityDet *h = new THaHelicityDet("H","Beam helicity");
	h->SetState(0,0,-1,1,0);
	a->AddDetector(h);
	gHaApps->Add(a);

// Rastered beam
	gHaApps->Add(new THaRasteredBeam("rb","Rastered Beamline"));
// Unrastered beam
	THaApparatus *BEAM = new THaUnRasteredBeam("urb","Beamline");
	gHaApps->Add(BEAM);

// add scaler banks
	THaScalerGroup *EvRightScalers = new THaScalerGroup("evright");
	gHaScalers->Add(EvRightScalers);
	THaScalerGroup *RightScalers = new THaScalerGroup("Right");
	gHaScalers->Add(RightScalers);

// add detectors that are not in the default config
	HRSR->AddDetector(new THaCherenkov("cer","Gas Cherenkov counter"));
	HRSR->AddDetector(new THaShower("ps","Preshower counter"));
	HRSR->AddDetector(new THaShower("sh","Shower counter"));

	gSystem->Load("libDynCheck.so");
	gHaApps->Add(new THaDynData("DR","Misc. Decoder Data"));
	gSystem->Load("libSepShift.so");

// Set up physics modules
	gHaPhysics->Add(new THaReactionPoint("rpr","Reaction vertex for Right","R","urb"));
//	gHaPhysics->Add(new THaGoldenTrack("R.gold","HRS-R Golden Track","R"));
	gHaPhysics->Add(new THaSeptumShiftCor("SepR","HRS-R Septum Shift correction","R","rpr"));
//	gHaPhysics->Add(new THaExtTarCor("CorR","HRS-R xtg correction","R","rpr"));
	gHaPhysics->Add(new THaExtTarCor("CorS","HRS-R xtg correction","SepR","rpr"));

// Set up the standard analyzer, if not already done
	THaAnalyzer *analyzer = THaAnalyzer::GetInstance();
	if (analyzer)
	{ analyzer->Close(); }
	else 
	{ analyzer = new THaAnalyzer; }

// Enable scalers
	analyzer->EnableScalers();

// Enable helicity
	analyzer->EnableHelicity();

// Define the analysis parameters	
	analyzer->SetCompressionLevel(1);
	TString s_outvars = allbase + "_outvars.def";
	TString s_cuts    = allbase + "_cuts.def";
	analyzer->SetOdefFile(s_outvars.Data());
	analyzer->SetCutFile(s_cuts.Data());

// run over all EXPERIMENT_<num>.dat.* files
	TString default_experiment = "gdh";
	TString experiment = gSystem->Getenv("EXPERIMENT");
	if (experiment == "") 
	{ experiment = default_experiment; }
	cout << experiment << endl;
	TString filename_prefix = experiment + "_" + run_number;
// Set output file names  These get renamed at the end of 
// the batch job depending on structure of jsub command.
	TString summary_filename = filename_prefix + "_" + allbase + ".log";
	TString  output_filename = filename_prefix + "_" + allbase + ".root";
	analyzer->SetSummaryFile(summary_filename.Data());
	cout <<  summary_filename.Data() << endl;
	analyzer->SetOutFile(output_filename.Data());
	cout <<  output_filename.Data() << endl;
	Int_t first_split_number = 0;
	Int_t max_split_number = split_number;
	if (which_ones == "just the first one")
	{ max_split_number = 0; }
//	else if (which_ones == "just this one")
//	{ first_split_number = split_number; }
	THaRun *run;
	TDatime run_start_time;
	for (Int_t current_split_number = first_split_number ; current_split_number <= max_split_number ; current_split_number++)
	{
		TString run_filename = test_path + filename_prefix + ".dat." + current_split_number;
		cout << run_filename << endl;
		run = new THaRun(run_filename.Data());
		cout << "First Print Statement:" << endl;
		run->Print();
		if (current_split_number == 0)
		{
//			run->SetLastEvent(100);
  			analyzer->Process(run);
			cout << "0 split number after process Print Statement:" << endl;
			run->Print();
			run_start_time = run->GetDate();
			cout << endl << endl << endl << endl;
			printf("%.6E\n",run->GetParameters()->GetBeamdE() );
			printf("%.6E\n",run->GetParameters()->GetBeamE()  );
			printf("%.6E\n",run->GetParameters()->GetBeamM()  );
			printf("%.6E\n",run->GetParameters()->GetBeamP()  );
			printf("%.6E\n",run->GetParameters()->GetBeamQ()  );
			printf("%.6E\n",run->GetParameters()->GetTgtM()   );
			cout << endl << endl << endl << endl;
		}
		else
		{
			cout << "neq 0 split number first Print Statement:" << endl;
			run->Print();
			run->SetDate(run_start_time);
			cout << "neq 0 split number after date set Print Statement:" << endl;
			run->Print();
			run->Init();
			cout << "neq 0 split number after init Print Statement:" << endl;
			run->Print();
			run->SetNumber(run_number);
			cout << "neq 0 split number after runnum set and before process Print Statement:" << endl;
			run->Print();
//			run->SetLastEvent(100);
	   		analyzer->Process(run);
			cout << "neq 0 split number after process Print Statement:" << endl;
			run->Print();
			cout << endl << endl << endl << endl;
			printf("%.6E\n",run->GetParameters()->GetBeamdE() );
			printf("%.6E\n",run->GetParameters()->GetBeamE()  );
			printf("%.6E\n",run->GetParameters()->GetBeamM()  );
			printf("%.6E\n",run->GetParameters()->GetBeamP()  );
			printf("%.6E\n",run->GetParameters()->GetBeamQ()  );
			printf("%.6E\n",run->GetParameters()->GetTgtM()   );
			cout << endl << endl << endl << endl;
		}
	}
}
