//
//	usage: .x replay.C(2358 , 0 , "replay_outvars.def" , "replay_cuts.def" , "replay" , "/cache/mss/halla/gdh/raw/" , "all")
//	   OR: analyzer  'replay.C(2358 , 0 , "replay_outvars.def" , "replay_cuts.def" , "replay" , "/cache/mss/halla/gdh/raw/" , "all")'
//			 ^   														^
//*****very important => since some input are strings enclosed in double quote ", the whole thing must be enclosed in single quotes '
//
//		(1) run number must be an integer
//		(2) split number must be an integer
//		(3) all other options must be strings enclosed in double quotes " "
//		(4) the path for the raw data file must end with a back slash "/", 
//		    => unless it is the present working directory in which case the string should be empty ""
//		(5) the last option is the split control:
//			[split control] = all                , do all splits files
//			[split control] = just the first one , do just the first (split file number = 0) file
//
//	date: 07/28/06
//
//	by: Jaideep Singh (originally jacked from V. Sulkosky who jacked it from probably a combination of R. Michaels and R. Feurbach
//
//	description: analzyer macro used to replay a raw data file, extract variables listed in def file, and create root file
//		     handles split runs using the quick fix by Rob/Vince
//

void replay(Int_t run_number = 2358 , Int_t split_number = 0 , TString outvars_filename = "replay_outvars.def" , TString cuts_filename = "replay_cuts.def" , TString output_basename = "replay" , TString raw_data_path = "" , TString which_ones = "all")
{
// Set up equipment
// For sagGDH, the left and right spetrometer runs have to 
// be replayed separately.
// add one spectrometer with the "standard" configuration
// (VDC planes, S1, and S2)
	THaApparatus *HRSR = new THaHRS("R","Right arm HRS");
	gHaApps->Add(HRSR);
//	HRSR->SetDebugAll(1);
//
// beam position and helicity
	THaApparatus *a = new THaIdealBeam("beam","Ideal beam");
	THaHelicityDet *h = new THaHelicityDet("H","Beam helicity");
	h->SetState(0,0,-1,1,0);
	a->AddDetector(h);
	gHaApps->Add(a);
//
// Rastered beam
	gHaApps->Add(new THaRasteredBeam("rb","Rastered Beamline"));
// Unrastered beam
//	THaApparatus *BEAM = new THaUnRasteredBeam("urb","Beamline");
//	gHaApps->Add(BEAM);
//
// add scaler banks
//	THaScalerGroup *EvRightScalers = new THaScalerGroup("evright");
//	gHaScalers->Add(EvRightScalers);
//	THaScalerGroup *RightScalers = new THaScalerGroup("Right");
//	gHaScalers->Add(RightScalers);
//
// add detectors that are not in the default config
	HRSR->AddDetector(new THaCherenkov("cer","Gas Cherenkov counter"));
	HRSR->AddDetector(new THaShower("ps","Preshower counter"));
	HRSR->AddDetector(new THaShower("sh","Shower counter"));
//
	gSystem->Load("libDynCheck.so");
	gHaApps->Add(new THaDynData("DR","Misc. Decoder Data"));
	gSystem->Load("libSepShift.so");

	Double_t mass_tg  = 0.0; // Target mass should come from the beam module 
// 	                            and run database.
//
// Set up physics modules
	gHaPhysics->Add(new THaReactionPoint("rpr","Reaction vertex for Right","R","rb"));
//	gHaPhysics->Add(new THaGoldenTrack("R.gold","HRS-R Golden Track","R"));
	gHaPhysics->Add(new THaExtTarCor("CorR","HRS-R xtg correction","R","rpr"));
	gHaPhysics->Add(new THaSeptumShiftCor("SepR","HRS-R Septum Shift correction",
					      "CorR","rpr","rb"));
	gHaPhysics->Add(new THaPrimaryKine("PK_r","Primary kinematics in HRS-R",
					   "SepR","rb",mass_tg));
//
// Set up the standard analyzer, if not already done
	THaAnalyzer *analyzer = THaAnalyzer::GetInstance();
	if (analyzer)
	{ analyzer->Close(); }
	else 
	{ analyzer = new THaAnalyzer; }
//
// Enable scalers
//	analyzer->EnableScalers();
//
// Enable helicity
	analyzer->EnableHelicity();
//
//	
// Some common masses in GeV from NIST website
//
//      Double_t mass_neutron   =  0.93956536;
//      Double_t mass_helium3   =  2.80839142;
//      Double_t mass_carbon    = 11.1848295;
//      Double_t mass_nitrogen  = 13.0435806;
//      Double_t mass_electron  =  0.510998918E-3;
//      Double_t mass_helium    =  3.727377922;
//      Double_t mass_proton    =  0.938272029;
//      Double_t mass_hydrogen  =  0.938272029;
//      Double_t mass_deuteron  =  1.87561282;
//      Double_t mass_deuterium =  1.87561282;
//
// Everthing past this point should be "standard"
// Setting up filenames of the inputs and outputs
// When a char* variable is expected, use the TString Data() method

	analyzer->SetCompressionLevel(1);

	analyzer->SetOdefFile(outvars_filename.Data());
	cout << endl << "Setting output variables definition file to: " << outvars_filename << endl;
	analyzer->SetCutFile(cuts_filename.Data());
	cout << "Setting cuts definition file to: " << cuts_filename << endl;

	TString default_experiment = "gdh";
	TString experiment = gSystem->Getenv("EXPERIMENT");
	if (experiment == "") 
	{ experiment = default_experiment; }
	TString filename_prefix = experiment + "_" + run_number;
	if (output_basename != "")
	{ output_basename = "_" + output_basename; }

	TString summary_filename = filename_prefix + output_basename + ".log";
	analyzer->SetSummaryFile(summary_filename.Data());
	cout << "Setting output log file name to: " << summary_filename << endl;
	TString  output_filename = filename_prefix + output_basename + ".root";
	analyzer->SetOutFile(output_filename.Data());
	cout << "Setting output root file name to: " << output_filename << endl;

	Int_t first_split_number = 0;
	Int_t max_split_number = split_number;
	if (which_ones == "just the first one")
	{ max_split_number = 0; }
// commented out because this option is probably not useful
//	else if (which_ones == "just this one")
//	{ first_split_number = split_number; }

	THaRun *run;
	TDatime run_start_time;
	for (Int_t current_split_number = first_split_number ; current_split_number <= max_split_number ; current_split_number++)
	{
		TString run_filename = raw_data_path + filename_prefix + ".dat." + current_split_number;
		run = new THaRun(run_filename.Data());
		cout << "Setting input raw data file to: " << run_filename << endl << endl;
		if (current_split_number == 0)
		{
//			run->SetLastEvent(100000);
  			analyzer->Process(run);
			run_start_time = run->GetDate();
		}
		else
		{
// in the latest analyzer, split files are handled: SetFilename => SetDate => SetNumber
//			run->SetFilename(run_filename.Data());
// in the version we use, split files are handled: SetDate => Init => SetNumber
// prescale factors are not preserved, but it probably does not affect the replay itself
			cout << endl << "Starting the split run data files" << endl;
			run->SetDate(run_start_time);
			run->Init();
			run->SetNumber(run_number);
//			run->SetLastEvent(100);
	   		analyzer->Process(run);
		}
		run->Print();
	}
	cout << endl << "Run " << run_number << " is done. Processed a total of " << ++split_number << " raw data file(s)." << endl;
}
